# gdbp

A wrapper for GDB's Python API, helping you write GDB Python scripts efficiently and intuitively.

## Installation

```sh
pip install gdbp
```

or

```sh
git clone https://github.com/ramikg/gdbp.git
cd gdbp
python setup.py install
```

## Supported platforms

- GDB 7.0+
- Python 2.7 and 3.0+
- Any GDB-supported architecture
